@@ -2,13 +2,13 @@ import os
 from dataclasses import dataclass
 from enum import Enum
 from subprocess import CompletedProcess
-from typing import Any, List, Optional, Tuple
+from typing import Any, List, Optional, Tuple, Callable
 import PyInquirer
 from fds.domain.commands import AddCommands
 from fds.domain.constants import MAX_THRESHOLD_SIZE
 from fds.logger import Logger
 from fds.services.pretty_print import PrettyPrint
-from fds.services.types import DvcAdd
+from fds.services.types import DvcAdd, InnerService
 from fds.utils import get_size_of_path, convert_bytes_to_readable, convert_bytes_to_string, execute_command, \
     append_line_to_file, check_git_ignore, check_dvc_ignore, does_file_exist, \
     construct_dvc_url_from_git_url_dagshub, get_input_from_user
@@ -30,28 +30,47 @@ class AddToDvc:
     file_to_skip: Optional[str]
 
 
-class DVCService(object):
+class DVCService(InnerService):
     """
     DVC Service responsible for all the dvc commands of fds
     """
 
     def __init__(self):
-        self.repo_path = os.path.curdir
+        self.repo_path = self.get_repo_path()
         self.logger = Logger.get_logger("fds.DVCService")
         self.printer = PrettyPrint()
         self.selection_message_count = 0
 
+    @staticmethod
+    def get_repo_path():
+
+        path_cmd = execute_command(["dvc", "root"], capture_output=True, ignorable_return_codes=[0, 253])
+        stderr = convert_bytes_to_string(path_cmd.stderr).strip()
+        # If its not inside dvc directory, then it means dvc is not initalized yet
+        if "not inside of a DVC repository" in stderr:
+            repo_path = os.path.curdir
+        else:
+            absolute_path = convert_bytes_to_string(path_cmd.stdout).strip()
+            repo_path = os.path.abspath(os.path.join(os.path.curdir, absolute_path))
+        return repo_path
+
+    def is_initialized(self):
+        return does_file_exist(f"{self.repo_path}/.dvc")
+
     def init(self):
         """
         Responsible for running dvc init
         :return:
         """
         # Check if dvc is already initialized
-        if does_file_exist(f"{self.repo_path}/.dvc"):
+        if self.is_initialized():
             return "DVC already initialized"
         execute_command(["dvc", "init", "--subdir"])
         return "DVC initialized successfully"
 
+    def is_initialized(self) -> Any:
+        return does_file_exist(f"{self.repo_path}/.dvc")
+
     def status(self) -> Any:
         """
         Responsible for running dvc status
@@ -273,10 +292,10 @@ class DVCService(object):
         password = get_input_from_user("Enter your DAGsHub token", type="password")
         return user_name, password
 
-    def push(self, remote: str) -> Any:
-        push_output_bytes = self.__execute_push_command(remote)
+    def __handle_dvc_auth(self, remote: str, handler: Callable) -> None:
+        output_bytes = handler()
         # Check if its unauthorized
-        if '401 Unauthorized' in convert_bytes_to_string(push_output_bytes.stderr):
+        if '401 Unauthorized' in convert_bytes_to_string(output_bytes.stderr):
             # Check if remote is DagsHub.com
             if "dagshub.com" in remote.lower():
                 user_name, password = self.__handle_dagshub_remote()
@@ -284,7 +303,7 @@ class DVCService(object):
                 self.printer.warn("Please enter your credentials, so we can pull from your dvc remote")
                 user_name = get_input_from_user("Enter your dvc username")
                 password = get_input_from_user("Enter your dvc password", type="password")
-            dvc_remote_modify=["dvc", "remote", "modify", remote, "--local"]
+            dvc_remote_modify = ["dvc", "remote", "modify", remote, "--local"]
             # Add auth basic
             execute_command(dvc_remote_modify+["auth", "basic"], capture_output=False)
             # Add username
@@ -292,11 +311,14 @@ class DVCService(object):
             # Add password
             execute_command(dvc_remote_modify+["user", password], capture_output=False)
             # Try to push again
-            push_output_bytes = self.__execute_push_command(remote)
-            if push_output_bytes.returncode != 0:
+            output_bytes = handler()
+            if output_bytes.returncode != 0:
                 # Not giving any message because we already print the message in execute_command
                 raise Exception()
 
+    def push(self, remote: str) -> Any:
+        self.__handle_dvc_auth(remote, lambda: self.__execute_push_command(remote))
+
     @staticmethod
     def __get_remotes_list() -> dict:
         config_list_cmd = execute_command(["dvc", "remote", "list"], capture_output=True)
@@ -361,5 +383,15 @@ class DVCService(object):
                         return 0
                 else:
                     remote_name = default_remote
+        self.__handle_dvc_auth(remote_name, lambda: execute_command(
+            ["dvc", "pull", "-r", remote_name],
+            capture_output=False,
+            capture_output_and_write_to_stdout=True))
 
-        execute_command(["dvc", "pull", "-r", remote_name], capture_output=False)
+    @staticmethod
+    def version() -> str:
+        """
+        Return current version of dvc
+        :return:
+        """
+        return convert_bytes_to_string(execute_command(["dvc", "--version"], capture_output=True).stdout)
