@@ -1,7 +1,7 @@
 import subprocess
 from pathlib import Path
 import os
-from typing import List, Union, Any
+from typing import List, Union, Any, Optional
 
 import humanize
 import select
@@ -9,6 +9,7 @@ import sys
 from fds.logger import Logger
 import PyInquirer
 
+
 def get_size_of_path(path: str) -> int:
     if os.path.isdir(path):
         return sum(p.stat().st_size for p in Path(path).rglob('*'))
@@ -31,8 +32,8 @@ def execute_command(command: Union[str, List[str]], shell: bool = False, capture
         output = subprocess.run(command, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
     elif capture_output_and_write_to_stdout:
         output = subprocess.Popen(command, shell=shell, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
-        stdout=[]
-        stderr=[]
+        stdout = []
+        stderr = []
         while True:
             reads = [output.stdout.fileno(), output.stderr.fileno()]
             ret = select.select(reads, [], [])
@@ -46,7 +47,7 @@ def execute_command(command: Union[str, List[str]], shell: bool = False, capture
                     read = output.stderr.readline()
                     sys.stderr.write(convert_bytes_to_string(read))
                     stderr.append(read)
-            if output.poll() != None:
+            if output.poll() is not None:
                 break
         # create a completed process to have same convention
         return subprocess.CompletedProcess(command, output.returncode, b''.join(stdout), b''.join(stderr))
@@ -63,6 +64,19 @@ def execute_command(command: Union[str, List[str]], shell: bool = False, capture
     return output
 
 
+def rerun_in_new_shell_and_exit(
+    cmd: Optional[List[str]] = None
+):
+    cmd = cmd or ["fds"] + sys.argv
+
+    output = execute_command(
+        cmd,
+        shell=True,
+        capture_output=False,
+    )
+    sys.exit(output.returncode)
+
+
 def append_line_to_file(filename: str, data: str) -> None:
     with open(filename, "a") as f:
         f.write(data)
