@@ -21,7 +21,7 @@ class TestFds(IntegrationTestCase):
         self.fds_service.init()
         super().create_fake_git_data()
         super().create_fake_dvc_data()
-        self.fds_service.add(".")
+        self.fds_service.add(["."])
         output = execute_command(["git", "status"], capture_output=True)
         # Check DVC add
         assert "new file:   large_file.dvc" in convert_bytes_to_string(output.stdout)
@@ -32,13 +32,26 @@ class TestFds(IntegrationTestCase):
         assert "new file:   git_data/file-3" in convert_bytes_to_string(output.stdout)
         assert "new file:   git_data/file-4" in convert_bytes_to_string(output.stdout)
 
+    @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.ADD_TO_DVC.value})
+    def test_add_multiple_paths(self, get_choice):
+        self.fds_service.init()
+        super().create_fake_git_data()
+        super().create_dummy_file("large_file_1", 11 * 1024)
+        super().create_dummy_file("large_file_2", 11 * 1024)
+        super().create_dummy_file("large_file_3", 11 * 1024)
+        self.fds_service.add(["large_file_1", "large_file_3"])
+        output = execute_command(["git", "status"], capture_output=True)
+        # Check DVC add
+        assert "new file:   large_file_3.dvc" in convert_bytes_to_string(output.stdout)
+        assert "new file:   large_file_1.dvc" in convert_bytes_to_string(output.stdout)
+        assert "\n\tlarge_file_2" in convert_bytes_to_string(output.stdout)
 
     @patch("fds.services.dvc_service.DVCService._get_choice", return_value={"selection_choice": DvcChoices.IGNORE.value})
     def test_add_dvc_ignore(self, get_choice):
         self.fds_service.init()
         super().create_fake_git_data()
         super().create_fake_dvc_data()
-        self.fds_service.add(".")
+        self.fds_service.add(["."])
         output = execute_command(["cat", ".dvcignore"], capture_output=True)
         assert "large_file" in convert_bytes_to_string(output.stdout)
 
@@ -47,7 +60,7 @@ class TestFds(IntegrationTestCase):
         self.fds_service.init()
         super().create_fake_git_data()
         super().create_fake_dvc_data()
-        self.fds_service.add(".")
+        self.fds_service.add(["."])
         self.fds_service.commit("Commit 1", True)
         output = execute_command(["git", "log", "--oneline"], capture_output=True)
         assert "Commit 1" in convert_bytes_to_string(output.stdout)
@@ -65,7 +78,7 @@ class TestFds(IntegrationTestCase):
         self.fds_service.init()
         super().create_fake_git_data()
         super().create_fake_dvc_data()
-        self.fds_service.add(".")
+        self.fds_service.add(["."])
         output = execute_command(["git", "status"], capture_output=True)
         # This means untracked, because added files will have new file: in git output
         assert "\n\tlarge_file\n\n" in convert_bytes_to_string(output.stdout)
@@ -73,7 +86,7 @@ class TestFds(IntegrationTestCase):
     def test_commit_git(self):
         self.fds_service.init()
         super().create_fake_git_data()
-        self.fds_service.add(".")
+        self.fds_service.add(["."])
         self.fds_service.commit("Commit 1", False)
         output = execute_command(["git", "log", "--oneline"], capture_output=True)
         assert "Commit 1" in convert_bytes_to_string(output.stdout)
